==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ManagedRuleExclusionSelectorMatchOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Comparison operator to apply to the selector when specifying which elements in the collection this exclusion applies to.
 */
public enum class ManagedRuleExclusionSelectorMatchOperator(
    public val javaValue:
    com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator> {
    Equals(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.Equals),
    Contains(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.Contains),
    StartsWith(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.StartsWith),
    EndsWith(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.EndsWith),
    EqualsAny(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.EqualsAny),
    ;

    override fun toJava():
        com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator = javaValue

    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator):
            ManagedRuleExclusionSelectorMatchOperator =
            ManagedRuleExclusionSelectorMatchOperator.values().first { it.javaValue == javaType }
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/network/kotlin/enums/ManagedRuleExclusionSelectorMatchOperator.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.network.kotlin.enums

import com.pulumi.kotlin.ConvertibleToJava
import kotlin.Suppress

/**
 * Comparison operator to apply to the selector when specifying which elements in the collection this exclusion applies to.
 */
public enum class ManagedRuleExclusionSelectorMatchOperator(
    public val javaValue: com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator,
) :
    ConvertibleToJava<com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator> {
    Equals(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.Equals),
    Contains(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.Contains),
    StartsWith(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.StartsWith),
    EndsWith(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.EndsWith),
    EqualsAny(com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator.EqualsAny),
    ;

    override fun toJava(): com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator = javaValue

    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.network.enums.ManagedRuleExclusionSelectorMatchOperator): ManagedRuleExclusionSelectorMatchOperator =
            ManagedRuleExclusionSelectorMatchOperator.values().first { it.javaValue == javaType }
    }
}
